@@ -103,6 +103,22 @@ class Assertions(object):
             Consts.RESULT_LIST.append('fail')
             raise
 
+    def assert_string_contains(self, expect_str, result):
+        """
+        断言字符串是否包含在实际结果中
+        :param expect_str:
+        :param result:
+        :return:
+        """
+        print("校验结果dict------------------------------", expect_str)
+        print("excepte_dict------------------------------", result)
+        try:
+            assert expect_str in result
+        except:
+            self.log.error("assertion error")
+            Consts.RESULT_LIST.append('fail')
+            raise
+
     def assert_head_error(self, expect_str, result):
         print("校验结果dict------------------------------", expect_str)
         print("excepte_dict------------------------------", result)
