@@ -6,7 +6,7 @@
 '''
 
 import xlrd
-from accio import logger
+from . import logger
 
 
 class Excel(object):
