@@ -1,5 +1,5 @@
 # -*- encoding: utf-8 -*-
-from accio import parse_tools
+from . import parse_tools
 import sys
 
 
