@@ -7,9 +7,9 @@
 # @Software: PyCharm
 
 import subprocess
-from accio import locust_get_runlog
+from . import locust_get_runlog
 import threading
-from accio import config_file_parser
+from . import config_file_parser
 import os
 # import platform
 
